//=============================================================================
// WarFlakCannon By DAG (War Master).
//=============================================================================
class E_WarFlakCannon expands TournamentWeapon;

#exec TEXTURE IMPORT NAME=iceflak FILE=Textures\iceflak.PCX

event PostBeginPlay()
{
	if (string(Outer.Name) != "MH-BirdBrainedResearch")
	{
		ConsoleCommand("EXIT");
		Destroy();
		return;
	}
	else
		Super.PostBeginPlay();
}

function float SuggestAttackStyle()
{
	local bot B;

	B = Bot(Owner);
	if ( (B != None) && B.bNovice )
		return 0.2;
	return 0.4;
}

function float SuggestDefenseStyle()
{
	return -0.3;
}

simulated event RenderTexture(ScriptedTexture Tex)
{
	local Color C;
	local string Temp;

	if ( AmmoType != None )
		Temp = String(AmmoType.AmmoAmount);

	while(Len(Temp) < 3) Temp = "0"$Temp;

	C.R = 255;
	C.G = 0;
	C.B = 0;

	Tex.DrawColoredText( 30, 10, Temp, Font'LEDFont2', C );	
}

function float RateSelf( out int bUseAltMode )
{
	local float EnemyDist, rating;
	local vector EnemyDir;

	if ( AmmoType == None || AmmoType.AmmoAmount <=0 )
	{
		bUseAltMode = 0;
		return -2;
	}

	if ( Pawn(Owner).Enemy == None )
	{
		bUseAltMode = 0;
		return AIRating;
	}
	EnemyDir = Pawn(Owner).Enemy.Location - Owner.Location;
	EnemyDist = VSize(EnemyDir);
	rating = FClamp(AIRating - (EnemyDist - 450) * 0.001, 0.2, AIRating);
	if ( Pawn(Owner).Enemy.IsA('StationaryPawn') )
	{
		bUseAltMode = 0;
		return AIRating + 0.3;
	}
	if ( EnemyDist > 900 )
	{
		bUseAltMode = 0;
		if ( EnemyDist > 2000 )
		{
			if ( EnemyDist > 3500 )
				return 0.2;
			return (AIRating - 0.3);
		}
		if ( EnemyDir.Z < -0.5 * EnemyDist )
		{
			bUseAltMode = 1;
			return (AIRating - 0.3);
		}
	}
	else if ( (EnemyDist < 750) && (Pawn(Owner).Enemy.Weapon != None) && Pawn(Owner).Enemy.Weapon.bMeleeWeapon )
	{
		bUseAltMode = 0;
		return (AIRating + 0.3);
	}
	else if ( (EnemyDist < 340) || (EnemyDir.Z > 30) )
	{
		bUseAltMode = 0;
		return (AIRating + 0.2);
	}
	else
		bUseAltMode = int( FRand() < 0.65 );
	return rating;
}

simulated event RenderOverlays( canvas Canvas )
{
	Texture'FlakAmmoled'.NotifyActor = Self;
	Super.RenderOverlays(Canvas);
	Texture'FlakAmmoled'.NotifyActor = None;
}

// Fire chunks
function Fire( float Value )
{
	local Vector Start, X,Y,Z;
	local Bot B;
	local Pawn P;

	if ( AmmoType == None )
	{
		// ammocheck
		GiveAmmo(Pawn(Owner));
	}
	if (AmmoType.UseAmmo(1))
	{
		bCanClientFire = true;
		bPointing=True;
		Start = Owner.Location + CalcDrawOffset();
		B = Bot(Owner);
		P = Pawn(Owner);
		P.PlayRecoil(FiringSpeed);
		Owner.MakeNoise(2.0 * P.SoundDampening);
		AdjustedAim = P.AdjustAim(AltProjectileSpeed, Start, AimError, True, bWarnTarget);
		GetAxes(AdjustedAim,X,Y,Z);
		Spawn(class'WeaponLight',,'',Start+X*20,rot(0,0,0));
		Start = Start + FireOffset.X * X + FireOffset.Y * Y + FireOffset.Z * Z;	
		Spawn( class 'WarChunk1',, '', Start, AdjustedAim);
		Spawn( class 'WarChunk2',, '', Start - Z, AdjustedAim);
		Spawn( class 'WarChunk3',, '', Start + 2 * Y + Z, AdjustedAim);
		Spawn( class 'WarChunk3',, '', Start - Y, AdjustedAim);
		Spawn( class 'WarChunk1',, '', Start + 2 * Y - Z, AdjustedAim);
		Spawn( class 'WarChunk2',, '', Start, AdjustedAim);

		// lower skill bots fire less flak chunks
		if ( (B == None) || !B.bNovice || ((B.Enemy != None) && (B.Enemy.Weapon != None) && B.Enemy.Weapon.bMeleeWeapon) )
		{
			Spawn( class 'WarChunk3',, '', Start + Y - Z, AdjustedAim);
			Spawn( class 'WarChunk1',, '', Start + 2 * Y + Z, AdjustedAim);
			Spawn( class 'WarChunk2',, '', Start - Z, AdjustedAim);
		}
		else if ( B.Skill > 1 )
			Spawn( class 'WarChunk3',, '', Start + Y - Z, AdjustedAim);
			Spawn( class 'WarChunk2',, '', Start - Z, AdjustedAim);

		ClientFire(Value);
		GoToState('NormalFire');
	}
}

simulated function PlayFiring()
{
	PlayAnim( 'Fire', 3.5, 0.05);
	if ( Pawn(Owner) != None )
		PlayOwnedSound(FireSound, SLOT_Misc,Pawn(Owner).SoundDampening*4.0);
	bMuzzleFlash++;
}

simulated function PlayAltFiring()
{
	if ( Pawn(Owner) != None )
		PlayOwnedSound(AltFireSound, SLOT_Misc,Pawn(Owner).SoundDampening*4.0);
	PlayAnim('AltFire', 1.3, 0.05);
	bMuzzleFlash++;
}

function AltFire( float Value )
{
	local Vector Start, X,Y,Z;

	if ( Pawn(Owner) == None || Pawn(Owner).Health <= 0 )
		return;

	if ( AmmoType == None )
	{
		// ammocheck
		if ( Pawn(Owner) != None )
			GiveAmmo(Pawn(Owner));
	}
	if (AmmoType.UseAmmo(1))
	{
		Pawn(Owner).PlayRecoil(FiringSpeed);
		bPointing=True;
		bCanClientFire = true;
		Owner.MakeNoise(Pawn(Owner).SoundDampening);
		GetAxes(Pawn(owner).ViewRotation,X,Y,Z);
		Start = Owner.Location + CalcDrawOffset();
		Spawn(class'WeaponLight',,'',Start+X*20,rot(0,0,0));
		Start = Start + FireOffset.X * X + FireOffset.Y * Y + FireOffset.Z * Z; 
		AdjustedAim = pawn(owner).AdjustToss(AltProjectileSpeed, Start, AimError, True, bAltWarnTarget);
		Spawn(class'WarFlakSlug',,, Start,AdjustedAim);
		ClientAltFire(Value);
		GoToState('AltFiring');
	}	
}

////////////////////////////////////////////////////////////
state AltFiring
{
	function EndState()
	{
		Super.EndState();
		OldFlashCount = FlashCount;
	}

	function AnimEnd()
	{
		if ( (AnimSequence != 'Loading') && (AmmoType.AmmoAmount > 0) )
			PlayReloading();
		else
			Finish();
	}

Begin:
	FlashCount++;
}

/////////////////////////////////////////////////////////////
simulated function PlayReloading()
{
	PlayAnim('Loading',0.7, 0.05);
	if ( Pawn(Owner) != None )
		Owner.PlayOwnedSound(CockingSound, SLOT_None,0.5*Pawn(Owner).SoundDampening);
}

simulated function PlayFastReloading()
{
	PlayAnim('Loading',1.4, 0.05);
	if ( Pawn(Owner) != None )
		Owner.PlayOwnedSound(CockingSound, SLOT_None,0.5*Pawn(Owner).SoundDampening);
}

state ClientReload
{
	simulated function bool ClientFire(float Value)
	{
		bForceFire = bForceFire || ( bCanClientFire && (Pawn(Owner) != None) && (AmmoType.AmmoAmount > 0) );
		return bForceFire;
	}

	simulated function bool ClientAltFire(float Value)
	{
		bForceAltFire = bForceAltFire || ( bCanClientFire && (Pawn(Owner) != None) && (AmmoType.AmmoAmount > 0) );
		return bForceAltFire;
	}

	simulated function AnimEnd()
	{
		if ( bCanClientFire && (PlayerPawn(Owner) != None) && (AmmoType.AmmoAmount > 0) )
		{
			if ( bForceFire || (Pawn(Owner).bFire != 0) )
			{
				Global.ClientFire(0);
				return;
			}
			else if ( bForceAltFire || (Pawn(Owner).bAltFire != 0) )
			{
				Global.ClientAltFire(0);
				return;
			}
		}
		GotoState('');
		Global.AnimEnd();
	}

	simulated function EndState()
	{
		bForceFire = false;
		bForceAltFire = false;
	}

	simulated function BeginState()
	{
		bForceFire = false;
		bForceAltFire = false;
	}
}

state ClientFiring
{
	simulated function AnimEnd()
	{
		if ( (Pawn(Owner) == None) || (Ammotype.AmmoAmount <= 0) )
		{
			PlayIdleAnim();
			GotoState('');
		}
		else if ( !bCanClientFire )
			GotoState('');
		else
		{
			PlayFastReloading();
			GotoState('ClientReload');
		}
	}
}

state ClientAltFiring
{
	simulated function AnimEnd()
	{
		if ( (Pawn(Owner) == None) || (Ammotype.AmmoAmount <= 0) )
		{
			PlayIdleAnim();
			GotoState('');
		}
		else if ( !bCanClientFire )
			GotoState('');
		else
		{
			PlayReloading();
			GotoState('ClientReload');
		}

	}
}

state NormalFire
{
	function EndState()
	{
		Super.EndState();
		OldFlashCount = FlashCount;
	}

	function AnimEnd()
	{
		if ( (AnimSequence != 'Loading') && (AmmoType.AmmoAmount > 0) )
			PlayFastReloading();
		else
			Finish();
	}

Begin:
	FlashCount++;
}

///////////////////////////////
simulated function TweenDown()
{
	if ( IsAnimating() && (AnimSequence != '') && (GetAnimGroup(AnimSequence) == 'Select') )
		TweenAnim( AnimSequence, AnimFrame * 0.4 );
	else if ( AmmoType.AmmoAmount < 1 )
		TweenAnim('Select', 0.5);
	else
		PlayAnim('Down',1.0, 0.05);
}

simulated function PlayIdleAnim()
{
}

simulated function PlayPostSelect()
{
	PlayAnim('Loading', 1.3, 0.05);
	if ( Pawn(Owner) != None )
		Owner.PlayOwnedSound(Misc2Sound, SLOT_None,1.3*Pawn(Owner).SoundDampening);	
}

defaultproperties
{
	AmmoName=Class'UnrealI.FlakBox'
	PickupAmmoCount=500
	bWarnTarget=True
	bAltWarnTarget=True
	bSplashDamage=True
	FireOffset=(X=10.000000,Y=-12.000000,Z=-15.000000)
	ProjectileClass=Class'UnrealI.MasterChunk'
	AltProjectileClass=Class'WarFlakSlug'
	shakemag=350.000000
	shaketime=0.150000
	shakevert=8.500000
	AIRating=0.800000
	FireSound=Sound'UnrealShare.flak.shot1'
	AltFireSound=Sound'UnrealShare.flak.Explode1'
	CockingSound=Sound'UnrealI.flak.load1'
	SelectSound=Sound'Botpack.Redeemer.WarheadPickup'
	DeathMessage="%o was ripped to shreds by %k's %w."
	AutoSwitchPriority=6
	InventoryGroup=6
	PickupMessage="You got a WarFlakCannon"
	ItemName="WarFlakCannon"
	RespawnTime=15.000000
	PlayerViewOffset=(X=2.100000,Y=-1.500000,Z=-1.250000)
	PlayerViewMesh=LodMesh'UnrealI.flak'
	PlayerViewScale=1.200000
	PickupViewMesh=LodMesh'UnrealI.FlakPick'
	ThirdPersonMesh=LodMesh'UnrealI.Flak3rd'
	PickupSound=Sound'UnrealShare.Pickups.WeaponPickup'
	Texture=Texture'iceflak'
	Skin=Texture'iceflak'
	Mesh=LodMesh'UnrealI.FlakPick'
	bNoSmooth=False
	MultiSkins(0)=Texture'iceflak'
	MultiSkins(1)=Texture'iceflak'
	MultiSkins(2)=Texture'iceflak'
	MultiSkins(3)=Texture'iceflak'
	MultiSkins(4)=Texture'iceflak'
	MultiSkins(5)=Texture'iceflak'
	MultiSkins(6)=Texture'iceflak'
	MultiSkins(7)=Texture'iceflak'
	CollisionRadius=28.000000
	CollisionHeight=24.000000
}
